#[repr(C)]pub struct WlanPhyGetTxPowerScenarioResponse {
pub scenario: TxPowerScenario,
}Fields
scenario: TxPowerScenarioTrait Implementations
Sourceimpl Clone for WlanPhyGetTxPowerScenarioResponse
impl Clone for WlanPhyGetTxPowerScenarioResponse
Sourcefn clone(&self) -> WlanPhyGetTxPowerScenarioResponse
fn clone(&self) -> WlanPhyGetTxPowerScenarioResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WlanPhyGetTxPowerScenarioResponse
Sourceimpl<___E> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for WlanPhyGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for WlanPhyGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhyGetTxPowerScenarioResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhyGetTxPowerScenarioResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for &'a WlanPhyGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for &'a WlanPhyGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> EncodeOption<Box<'static, WlanPhyGetTxPowerScenarioResponse>, ___E> for WlanPhyGetTxPowerScenarioResponsewhere
___E: Encoder + ?Sized,
WlanPhyGetTxPowerScenarioResponse: Encode<WlanPhyGetTxPowerScenarioResponse, ___E>,
impl<___E> EncodeOption<Box<'static, WlanPhyGetTxPowerScenarioResponse>, ___E> for WlanPhyGetTxPowerScenarioResponsewhere
___E: Encoder + ?Sized,
WlanPhyGetTxPowerScenarioResponse: Encode<WlanPhyGetTxPowerScenarioResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanPhyGetTxPowerScenarioResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanPhyGetTxPowerScenarioResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, WlanPhyGetTxPowerScenarioResponse>, ___E> for &'a WlanPhyGetTxPowerScenarioResponsewhere
___E: Encoder + ?Sized,
&'a WlanPhyGetTxPowerScenarioResponse: Encode<WlanPhyGetTxPowerScenarioResponse, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, WlanPhyGetTxPowerScenarioResponse>, ___E> for &'a WlanPhyGetTxPowerScenarioResponsewhere
___E: Encoder + ?Sized,
&'a WlanPhyGetTxPowerScenarioResponse: Encode<WlanPhyGetTxPowerScenarioResponse, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanPhyGetTxPowerScenarioResponse>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanPhyGetTxPowerScenarioResponse>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl Eq for WlanPhyGetTxPowerScenarioResponse
Sourceimpl FromWire<WlanPhyGetTxPowerScenarioResponse> for WlanPhyGetTxPowerScenarioResponse
impl FromWire<WlanPhyGetTxPowerScenarioResponse> for WlanPhyGetTxPowerScenarioResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetTxPowerScenarioResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetTxPowerScenarioResponse, Self>
Sourcefn from_wire(wire: WlanPhyGetTxPowerScenarioResponse) -> Self
fn from_wire(wire: WlanPhyGetTxPowerScenarioResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<WlanPhyGetTxPowerScenarioResponse> for WlanPhyGetTxPowerScenarioResponse
impl FromWireRef<WlanPhyGetTxPowerScenarioResponse> for WlanPhyGetTxPowerScenarioResponse
Sourcefn from_wire_ref(wire: &WlanPhyGetTxPowerScenarioResponse) -> Self
fn from_wire_ref(wire: &WlanPhyGetTxPowerScenarioResponse) -> Self
Converts the given reference to this type.
Sourceimpl Ord for WlanPhyGetTxPowerScenarioResponse
impl Ord for WlanPhyGetTxPowerScenarioResponse
Sourcefn cmp(&self, other: &WlanPhyGetTxPowerScenarioResponse) -> Ordering
fn cmp(&self, other: &WlanPhyGetTxPowerScenarioResponse) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanPhyGetTxPowerScenarioResponse
impl PartialEq for WlanPhyGetTxPowerScenarioResponse
Sourcefn eq(&self, other: &WlanPhyGetTxPowerScenarioResponse) -> bool
fn eq(&self, other: &WlanPhyGetTxPowerScenarioResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanPhyGetTxPowerScenarioResponse
impl PartialOrd for WlanPhyGetTxPowerScenarioResponse
impl StructuralPartialEq for WlanPhyGetTxPowerScenarioResponse