WlanPhyNotifyLocalServerHandler

Trait WlanPhyNotifyLocalServerHandler 

pub trait WlanPhyNotifyLocalServerHandler<___T: Transport = Channel> {
    // Required methods
    fn on_critical_error(
        &mut self,
        request: Request<OnCriticalError, ___T>,
        responder: Responder<OnCriticalError, ___T>,
    ) -> impl Future<Output = ()>;
    fn on_country_code_change(
        &mut self,
        request: Request<OnCountryCodeChange, ___T>,
        responder: Responder<OnCountryCodeChange, ___T>,
    ) -> impl Future<Output = ()>;

    // Provided method
    fn on_unknown_interaction(
        &mut self,
        ordinal: u64,
    ) -> impl Future<Output = ()> { ... }
}
A server handler for the WlanPhyNotify protocol.

See WlanPhyNotify for more details.

Required Methods

fn on_critical_error( &mut self, request: Request<OnCriticalError, ___T>, responder: Responder<OnCriticalError, ___T>, ) -> impl Future<Output = ()>

Indicate to the receiver that the PHY has encountered a critical error specifying a reason code.

fn on_country_code_change( &mut self, request: Request<OnCountryCodeChange, ___T>, responder: Responder<OnCountryCodeChange, ___T>, ) -> impl Future<Output = ()>

Indicate to the receiver that the firmware running on wlan hardware has detected a change in country code.

Provided Methods

fn on_unknown_interaction(&mut self, ordinal: u64) -> impl Future<Output = ()>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<___H, ___T> WlanPhyNotifyLocalServerHandler<___T> for Local<___H>
where ___H: WlanPhyNotifyServerHandler<___T>, ___T: Transport,

Source

async fn on_critical_error( &mut self, request: Request<OnCriticalError, ___T>, responder: Responder<OnCriticalError, ___T>, )

Source

async fn on_country_code_change( &mut self, request: Request<OnCountryCodeChange, ___T>, responder: Responder<OnCountryCodeChange, ___T>, )

Source

async fn on_unknown_interaction(&mut self, ordinal: u64)

Implementors