#[repr(C)]pub struct WlanPhyGetCountryResponse {
pub country: [u8; 2],
}Expand description
The wire type corresponding to WlanPhyGetCountryResponse.
Fields
country: [u8; 2]Trait Implementations
Sourceimpl Clone for WlanPhyGetCountryResponse
impl Clone for WlanPhyGetCountryResponse
Sourcefn clone(&self) -> WlanPhyGetCountryResponse
fn clone(&self) -> WlanPhyGetCountryResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for WlanPhyGetCountryResponse
impl Constrained for WlanPhyGetCountryResponse
Sourceimpl Debug for WlanPhyGetCountryResponse
impl Debug for WlanPhyGetCountryResponse
Sourceimpl<___D> Decode<___D> for WlanPhyGetCountryResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for WlanPhyGetCountryResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<WlanPhyGetCountryResponse, ___E> for WlanPhyGetCountryResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanPhyGetCountryResponse, ___E> for WlanPhyGetCountryResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhyGetCountryResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhyGetCountryResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetCountryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetCountryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<WlanPhyGetCountryResponse, ___E> for &'a WlanPhyGetCountryResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanPhyGetCountryResponse, ___E> for &'a WlanPhyGetCountryResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetCountryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetCountryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<WlanPhyGetCountryResponse, ___E> for WlanPhyGetCountryResponse<T0>
impl<___E, T0> Encode<WlanPhyGetCountryResponse, ___E> for WlanPhyGetCountryResponse<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetCountryResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetCountryResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<WlanPhyGetCountryResponse> for WlanPhyGetCountryResponse
impl FromWire<WlanPhyGetCountryResponse> for WlanPhyGetCountryResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetCountryResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetCountryResponse, Self>
Sourcefn from_wire(wire: WlanPhyGetCountryResponse) -> Self
fn from_wire(wire: WlanPhyGetCountryResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<WlanPhyGetCountryResponse> for WlanPhyGetCountryResponse
impl FromWireRef<WlanPhyGetCountryResponse> for WlanPhyGetCountryResponse
Sourcefn from_wire_ref(wire: &WlanPhyGetCountryResponse) -> Self
fn from_wire_ref(wire: &WlanPhyGetCountryResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for WlanPhyGetCountryResponse
impl IntoNatural for WlanPhyGetCountryResponse
Sourcetype Natural = WlanPhyGetCountryResponse
type Natural = WlanPhyGetCountryResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for WlanPhyGetCountryResponse
impl Wire for WlanPhyGetCountryResponse
Sourcetype Narrowed<'de> = WlanPhyGetCountryResponse
type Narrowed<'de> = WlanPhyGetCountryResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.