#[repr(C)]pub struct WlanPhyGetTxPowerScenarioResponse {
pub scenario: TxPowerScenario,
}Expand description
The wire type corresponding to WlanPhyGetTxPowerScenarioResponse.
Fields
scenario: TxPowerScenarioTrait Implementations
Sourceimpl Clone for WlanPhyGetTxPowerScenarioResponse
impl Clone for WlanPhyGetTxPowerScenarioResponse
Sourcefn clone(&self) -> WlanPhyGetTxPowerScenarioResponse
fn clone(&self) -> WlanPhyGetTxPowerScenarioResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for WlanPhyGetTxPowerScenarioResponse
impl Constrained for WlanPhyGetTxPowerScenarioResponse
Sourceimpl<___D> Decode<___D> for WlanPhyGetTxPowerScenarioResponsewhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for WlanPhyGetTxPowerScenarioResponsewhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for WlanPhyGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for WlanPhyGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhyGetTxPowerScenarioResponse>
const COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhyGetTxPowerScenarioResponse>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for &'a WlanPhyGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for &'a WlanPhyGetTxPowerScenarioResponsewhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for WlanPhyGetTxPowerScenarioResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<TxPowerScenario, ___E>,
impl<___E, T0> Encode<WlanPhyGetTxPowerScenarioResponse, ___E> for WlanPhyGetTxPowerScenarioResponse<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<TxPowerScenario, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhyGetTxPowerScenarioResponse>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<WlanPhyGetTxPowerScenarioResponse> for WlanPhyGetTxPowerScenarioResponse
impl FromWire<WlanPhyGetTxPowerScenarioResponse> for WlanPhyGetTxPowerScenarioResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetTxPowerScenarioResponse, Self>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhyGetTxPowerScenarioResponse, Self>
Sourcefn from_wire(wire: WlanPhyGetTxPowerScenarioResponse) -> Self
fn from_wire(wire: WlanPhyGetTxPowerScenarioResponse) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<WlanPhyGetTxPowerScenarioResponse> for WlanPhyGetTxPowerScenarioResponse
impl FromWireRef<WlanPhyGetTxPowerScenarioResponse> for WlanPhyGetTxPowerScenarioResponse
Sourcefn from_wire_ref(wire: &WlanPhyGetTxPowerScenarioResponse) -> Self
fn from_wire_ref(wire: &WlanPhyGetTxPowerScenarioResponse) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for WlanPhyGetTxPowerScenarioResponse
impl IntoNatural for WlanPhyGetTxPowerScenarioResponse
Sourcetype Natural = WlanPhyGetTxPowerScenarioResponse
type Natural = WlanPhyGetTxPowerScenarioResponse
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for WlanPhyGetTxPowerScenarioResponse
impl Wire for WlanPhyGetTxPowerScenarioResponse
Sourcetype Narrowed<'de> = WlanPhyGetTxPowerScenarioResponse
type Narrowed<'de> = WlanPhyGetTxPowerScenarioResponse
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.