#[repr(C)]pub struct WlanPhySetCountryRequest {
pub country: [u8; 2],
}Expand description
The wire type corresponding to WlanPhySetCountryRequest.
Fields
country: [u8; 2]Trait Implementations
Sourceimpl Clone for WlanPhySetCountryRequest
impl Clone for WlanPhySetCountryRequest
Sourcefn clone(&self) -> WlanPhySetCountryRequest
fn clone(&self) -> WlanPhySetCountryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for WlanPhySetCountryRequest
impl Constrained for WlanPhySetCountryRequest
Sourceimpl Debug for WlanPhySetCountryRequest
impl Debug for WlanPhySetCountryRequest
Sourceimpl<___D> Decode<___D> for WlanPhySetCountryRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for WlanPhySetCountryRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<___E> Encode<WlanPhySetCountryRequest, ___E> for WlanPhySetCountryRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanPhySetCountryRequest, ___E> for WlanPhySetCountryRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhySetCountryRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, WlanPhySetCountryRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhySetCountryRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhySetCountryRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> Encode<WlanPhySetCountryRequest, ___E> for &'a WlanPhySetCountryRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanPhySetCountryRequest, ___E> for &'a WlanPhySetCountryRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhySetCountryRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhySetCountryRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E, T0> Encode<WlanPhySetCountryRequest, ___E> for WlanPhySetCountryRequest<T0>
impl<___E, T0> Encode<WlanPhySetCountryRequest, ___E> for WlanPhySetCountryRequest<T0>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanPhySetCountryRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanPhySetCountryRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<WlanPhySetCountryRequest> for WlanPhySetCountryRequest
impl FromWire<WlanPhySetCountryRequest> for WlanPhySetCountryRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<WlanPhySetCountryRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<WlanPhySetCountryRequest, Self>
Sourcefn from_wire(wire: WlanPhySetCountryRequest) -> Self
fn from_wire(wire: WlanPhySetCountryRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<WlanPhySetCountryRequest> for WlanPhySetCountryRequest
impl FromWireRef<WlanPhySetCountryRequest> for WlanPhySetCountryRequest
Sourcefn from_wire_ref(wire: &WlanPhySetCountryRequest) -> Self
fn from_wire_ref(wire: &WlanPhySetCountryRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for WlanPhySetCountryRequest
impl IntoNatural for WlanPhySetCountryRequest
Sourcetype Natural = WlanPhySetCountryRequest
type Natural = WlanPhySetCountryRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for WlanPhySetCountryRequest
impl Wire for WlanPhySetCountryRequest
Sourcetype Narrowed<'de> = WlanPhySetCountryRequest
type Narrowed<'de> = WlanPhySetCountryRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.